@@ -2,13 +2,17 @@ package Test2::Compare::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.000055';
+our $VERSION = '0.000069';
 
-use Carp qw/confess/;
+use Carp qw/confess croak/;
+use Scalar::Util qw/blessed/;
 
-use Test2::Util::Sub qw/sub_info/;
+use Sub::Info qw/sub_info/;
 use Test2::Compare::Delta();
 
+use overload bool => sub { 0 };
+use overload '""' => sub { $_[0] };
+
 sub MAX_CYCLES() { 75 }
 
 use Test2::Util::HashBase qw{builder _file _lines _info called};
@@ -19,10 +23,18 @@ use Test2::Util::HashBase qw{builder _file _lines _info called};
     *set_file  = \&set__file;
 }
 
+sub clone {
+    my $self = shift;
+    my $class = blessed($self);
+
+    # Shallow copy is good enough for all the current compare types.
+    return bless({%$self}, $class);
+}
+
 sub init {
     my $self = shift;
-    $self->{_lines} = delete $self->{lines} if exists $self->{lines};
-    $self->{_file}  = delete $self->{file}  if exists $self->{file};
+    $self->{+_LINES} = delete $self->{lines} if exists $self->{lines};
+    $self->{+_FILE}  = delete $self->{file}  if exists $self->{file};
 }
 
 sub file {
@@ -85,7 +97,7 @@ sub run {
     my $got = $exists ? $params{got} : undef;
 
     # Prevent infinite cycles
-    if ($got && ref $got) {
+    if (defined($got) && ref $got) {
         die "Cycle detected in comparison, aborting"
             if $seen->{$got} && $seen->{$got} >= MAX_CYCLES;
         $seen->{$got}++;
@@ -94,7 +106,7 @@ sub run {
     my $ok = $self->verify(%params);
     my @deltas = $ok ? $self->deltas(%params) : ();
 
-    $seen->{$got}-- if $got && ref $got;
+    $seen->{$got}-- if defined $got && ref $got;
 
     return if $ok && !@deltas;
 
